from distutils.core import setup

setup(
    name='gsnester',
    version='1.2.0',
    py_modules = ['gsnester'],
    author = 'Geetika Sharma',
    author_email = 'geetusharma7@gmail.com',
    description = 'Simple printer for nested lists'
    )
